==> edge-login-ui-rn-2.12.0.tgz: package/lib/components/navigation/Router.js <==
import * as React from 'react';
import { View } from 'react-native';
import { useSelector } from '../../types/ReduxTypes';
import { MaybeProvideLoginUi } from '../publicApi/LoginUiProvider';
import { ChangePasswordScene, NewAccountPasswordScene, ResecurePasswordScene, UpgradePasswordScene } from '../scenes/ChangePasswordScene';
import { ChangePinScene, NewAccountPinScene, ResecurePinScene } from '../scenes/ChangePinScene';
import { ChangeRecoveryScene } from '../scenes/existingAccout/ChangeRecoveryScene';
import { OtpRepairScene } from '../scenes/existingAccout/OtpRepairScene';
import { SecurityAlertsScene } from '../scenes/existingAccout/SecurityAlertsScene';
import { LandingScene } from '../scenes/LandingScene';
import { LoadingScene } from '../scenes/LoadingScene';
import { NewAccountReviewScene, UpgradeReviewScene } from '../scenes/newAccount/NewAccountReviewScene';
import { NewAccountTosScene, UpgradeTosScene } from '../scenes/newAccount/NewAccountTosScene';
import { NewAccountUsernameScene, UpgradeUsernameScene } from '../scenes/newAccount/NewAccountUsernameScene';
import { NewAccountWelcomeScene } from '../scenes/newAccount/NewAccountWelcomeScene';
import { OtpErrorScene } from '../scenes/OtpErrorScene';
import { PasswordLoginScene } from '../scenes/PasswordLoginScene';
import { PinLoginScene } from '../scenes/PinLoginScene';
import { RecoveryLoginScene } from '../scenes/RecoveryLoginScene';
import { WaitScene } from '../scenes/WaitScene';
export function Router(props) {
    const route = useSelector(state => state.scene);
    function renderContent() {
        switch (route.name) {
            case 'changePassword':
                return React.createElement(ChangePasswordScene, { route: route });
            case 'changePin':
                return React.createElement(ChangePinScene, { route: route });
            case 'changeRecovery':
                return React.createElement(ChangeRecoveryScene, { branding: props.branding, route: route });
            case 'newAccountWelcome':
                return (React.createElement(NewAccountWelcomeScene, { branding: props.branding, route: route }));
            case 'newAccountUsername':
                return (React.createElement(NewAccountUsernameScene, { branding: props.branding, route: route }));
            case 'newAccountPassword':
                return React.createElement(NewAccountPasswordScene, { route: route });
            case 'newAccountPin':
                return React.createElement(NewAccountPinScene, { route: route });
            case 'newAccountTos':
                return React.createElement(NewAccountTosScene, { branding: props.branding, route: route });
            case 'newAccountWait':
                return React.createElement(WaitScene, { route: route });
            case 'newAccountReview':
                return React.createElement(NewAccountReviewScene, { branding: props.branding, route: route });
            case 'landing':
                return React.createElement(LandingScene, { branding: props.branding, route: route });
            case 'loading':
                return React.createElement(LoadingScene, { branding: props.branding, route: route });
            case 'otpError':
                return React.createElement(OtpErrorScene, { route: route });
            case 'otpRepair':
                return React.createElement(OtpRepairScene, { branding: props.branding, route: route });
            case 'passwordLogin':
                return React.createElement(PasswordLoginScene, { branding: props.branding, route: route });
            case 'pinLogin':
                return React.createElement(PinLoginScene, { branding: props.branding, route: route });
            case 'recoveryLogin':
                return React.createElement(RecoveryLoginScene, { route: route });
            case 'resecurePassword':
                return React.createElement(ResecurePasswordScene, { route: route });
            case 'resecurePin':
                return React.createElement(ResecurePinScene, { route: route });
            case 'securityAlert':
                return React.createElement(SecurityAlertsScene, { route: route });
            case 'upgradeAccountReview':
                return React.createElement(UpgradeReviewScene, { branding: props.branding, route: route });
            case 'upgradePassword':
                return React.createElement(UpgradePasswordScene, { route: route });
            case 'upgradeTos':
                return React.createElement(UpgradeTosScene, { branding: props.branding, route: route });
            case 'upgradeUsername':
                return React.createElement(UpgradeUsernameScene, { branding: props.branding, route: route });
        }
    }
    return (React.createElement(MaybeProvideLoginUi, null,
        React.createElement(View, { style: styles.container }, renderContent())));
}
const styles = {
    container: {
        flex: 1,
        width: '100%',
        height: '100%'
    }
};

==> edge-login-ui-rn-2.20.0.tgz: package/lib/components/navigation/Router.js <==
import * as React from 'react';
import { View } from 'react-native';
import { useSelector } from '../../types/ReduxTypes';
import { MaybeProvideLoginUi } from '../publicApi/LoginUiProvider';
import { ChangePasswordScene, NewAccountPasswordScene, ResecurePasswordScene, UpgradePasswordScene } from '../scenes/ChangePasswordScene';
import { ChangePinScene, NewAccountPinScene, ResecurePinScene } from '../scenes/ChangePinScene';
import { ChangeRecoveryScene } from '../scenes/existingAccout/ChangeRecoveryScene';
import { OtpRepairScene } from '../scenes/existingAccout/OtpRepairScene';
import { SecurityAlertsScene } from '../scenes/existingAccout/SecurityAlertsScene';
import { LandingScene } from '../scenes/LandingScene';
import { LoadingScene } from '../scenes/LoadingScene';
import { NewAccountReviewScene, UpgradeReviewScene } from '../scenes/newAccount/NewAccountReviewScene';
import { NewAccountTosScene, UpgradeTosScene } from '../scenes/newAccount/NewAccountTosScene';
import { NewAccountUsernameScene, UpgradeUsernameScene } from '../scenes/newAccount/NewAccountUsernameScene';
import { NewAccountWelcomeScene } from '../scenes/newAccount/NewAccountWelcomeScene';
import { OtpErrorScene } from '../scenes/OtpErrorScene';
import { PasswordLoginScene } from '../scenes/PasswordLoginScene';
import { PinLoginScene } from '../scenes/PinLoginScene';
import { RecoveryLoginScene } from '../scenes/RecoveryLoginScene';
import { WaitScene } from '../scenes/WaitScene';
export function Router(props) {
    const route = useSelector(state => state.scene);
    function renderContent() {
        switch (route.name) {
            case 'changePassword':
                return React.createElement(ChangePasswordScene, { route: route });
            case 'changePin':
                return React.createElement(ChangePinScene, { route: route });
            case 'changeRecovery':
                return React.createElement(ChangeRecoveryScene, { branding: props.branding, route: route });
            case 'newAccountWelcome':
                return (React.createElement(NewAccountWelcomeScene, { branding: props.branding, route: route }));
            case 'newAccountUsername':
                return (React.createElement(NewAccountUsernameScene, { branding: props.branding, route: route }));
            case 'newAccountPassword':
                return React.createElement(NewAccountPasswordScene, { route: route });
            case 'newAccountPin':
                return React.createElement(NewAccountPinScene, { route: route });
            case 'newAccountTos':
                return React.createElement(NewAccountTosScene, { branding: props.branding, route: route });
            case 'newAccountWait':
                return React.createElement(WaitScene, { route: route });
            case 'newAccountReview':
                return React.createElement(NewAccountReviewScene, { branding: props.branding, route: route });
            case 'landing':
                return React.createElement(LandingScene, { branding: props.branding, route: route });
            case 'loading':
                return React.createElement(LoadingScene, { route: route });
            case 'otpError':
                return React.createElement(OtpErrorScene, { route: route });
            case 'otpRepair':
                return React.createElement(OtpRepairScene, { branding: props.branding, route: route });
            case 'passwordLogin':
                return React.createElement(PasswordLoginScene, { branding: props.branding, route: route });
            case 'pinLogin':
                return React.createElement(PinLoginScene, { branding: props.branding, route: route });
            case 'recoveryLogin':
                return React.createElement(RecoveryLoginScene, { route: route });
            case 'resecurePassword':
                return React.createElement(ResecurePasswordScene, { route: route });
            case 'resecurePin':
                return React.createElement(ResecurePinScene, { route: route });
            case 'securityAlert':
                return React.createElement(SecurityAlertsScene, { route: route });
            case 'upgradeAccountReview':
                return React.createElement(UpgradeReviewScene, { branding: props.branding, route: route });
            case 'upgradePassword':
                return React.createElement(UpgradePasswordScene, { route: route });
            case 'upgradeTos':
                return React.createElement(UpgradeTosScene, { branding: props.branding, route: route });
            case 'upgradeUsername':
                return React.createElement(UpgradeUsernameScene, { branding: props.branding, route: route });
        }
    }
    return (React.createElement(MaybeProvideLoginUi, null,
        React.createElement(View, { style: styles.container }, renderContent())));
}
const styles = {
    container: {
        flex: 1,
        width: '100%',
        height: '100%'
    }
};
